| Title: | Gives access to a Italian dialect translation services |
|---|---|
| Description: | Gives access to a Hessian translation service. |
| Authors: | Fabio Votta [aut, cre] |
| Maintainer: | Fabio Votta <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-08 06:01:08 UTC |
| Source: | https://github.com/favstats/rdialetti |
Translates Italian to Napoletano
get_napoletano(txt)get_napoletano(txt)
txt |
provide a text you want to translate from Iatlian into Napoletano |